Module: Expedition

Defined in:
lib/expedition.rb,
lib/expedition/client.rb,
lib/expedition/status.rb,
lib/expedition/version.rb,
lib/expedition/response.rb

Defined Under Namespace

Classes: Client, Response, Status

Constant Summary collapse

VERSION =
'0.4.0'.freeze

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.clientClient

Returns the default client for connection to localhost on port 4028. Used for simple scripts that access the Expedition constant directly.



12
13
14
# File 'lib/expedition.rb', line 12

def client
  @client
end

Class Method Details

.new(host = 'localhost', port = 4028) ⇒ Client

Initializes a new Client.



28
29
30
# File 'lib/expedition.rb', line 28

def self.new(host = 'localhost', port = 4028)
  Client.new(host, port)
end